{
  config,
  lib,
  ...
}:
with lib; let
  cfg = config.features.desktop.hyprland;
in {
  imports = [
    ../common
    ./dotfiles
    ./home.nix
    ../features/cli
    ../features/coding
    ../features/desktop
    #./services/librechat.nix
  ];

  options.features.desktop.hyprland.enable =
    mkEnableOption "enable Hyprland";

  config = mkMerge [
    # Base configuration
    {
      xdg = {
        # TODO: better structure
        enable = true;
        configFile."mimeapps.list".force = true;
        mimeApps = {
          enable = true;
          associations.added = {
            "application/zip" = ["org.gnome.FileRoller.desktop"];
            "application/csv" = ["calc.desktop"];
            "application/pdf" = ["io.github.zen_browser.zen.desktop"];
            "x-scheme-handler/http" = ["io.github.zen_browser.zen.desktop"];
            "x-scheme-handler/https" = ["io.github.zen_browser.zen.desktop"];
          };
          defaultApplications = {
            "application/zip" = ["org.gnome.FileRoller.desktop"];
            "application/csv" = ["calc.desktop"];
            "application/pdf" = ["io.github.zen_browser.zen.desktop"];
            "application/md" = ["dev.zed.Zed.desktop"];
            "application/text" = ["dev.zed.Zed.desktop"];
            "x-scheme-handler/http" = ["io.github.zen_browser.zen.desktop"];
            "x-scheme-handler/https" = ["io.github.zen_browser.zen.desktop"];
          };
        };
      };
      features = {
        cli = {
          fish.enable = true;
          fzf.enable = true;
          fastfetch.enable = true;
          secrets.enable = true;
          starship.enable = true;
        };
        desktop = {
          coding.enable = true;
          crypto.enable = true;
          gaming.enable = true;
          hyprland.enable = true;
          media.enable = true;
          office.enable = true;
          rofi.enable = true;
          fonts.enable = true;
          wayland.enable = true;
        };
      };
    }

    (mkIf cfg.enable {
      wayland.windowManager.hyprland = {
        enable = true;
        settings = {
          monitor = [
            "eDP-1,preferred,0x0,1.25"
            "HDMI-A-1,preferred,2560x0,1"
          ];
          workspace = [
            "1, monitor:eDP-1, default:true"
            "2, monitor:eDP-1"
            "3, monitor:eDP-1"
            "4, monitor:HDMI-A-1"
            "5, monitor:HDMI-A-1,border:false,rounding:false"
            "6, monitor:HDMI-A-1"
          ];
          windowrulev2 = [
            "workspace 1,class:dev.zed.Zed"
            "workspace 2,class:(com.obsproject.Studio)"
            "workspace 4,opacity 1.0, class:(chromium-browser)"
            "workspace 4,opacity 1.0, class:(zen)"
            "fullscreen,class:^steam_app_\\d+$"
            "workspace 5,class:^steam_app_\\d+$"
          ];
        };
      };
    })
  ];
}
